@@ -18,7 +18,7 @@
 
 #include "utils.h"
 #include "commands.h"
-#include "cmds-inspect-dump-super.h"
+#include "help.h"
 
 int main(int argc, char **argv)
 {
@@ -27,6 +27,9 @@ int main(int argc, char **argv)
 
 	set_argv0(argv);
 
+	warning(
+"\nthe tool has been deprecated, please use 'btrfs inspect-internal dump-super' instead\n");
+
 	if (argc > 1 && !strcmp(argv[1], "--help"))
 		usage(cmd_inspect_dump_super_usage);
 
